@@ -90,9 +90,7 @@ def extract_info(image: ee.Image, county: ee.Geometry, n_rois: int = 5) -> list:
             roi_means.append(roi_mean)
 
         return np.mean(roi_means, axis=0)
-    # except Exception as e:
-        # raise Exception(f"Error in extract_info: {str(e)}") from e
-    except :
+    except Exception:
         # return an np.zeros
         np.array([0.] * 17)
 
